@@ -338,7 +338,8 @@ void Sudoku::FillRandom()
   assert(found);
 }
 
-void Sudoku::GenerateRiddle(Sudoku &riddle, size_t minimumPointLimit)
+void Sudoku::GenerateRiddle(Sudoku &riddle, size_t minimumPointLimit,
+                            const AbortTester& abortTester)
 {
   time_t              firstTime=0;
   Sudoku              solution=riddle;
@@ -353,6 +354,10 @@ void Sudoku::GenerateRiddle(Sudoku &riddle, size_t minimumPointLimit)
     bool                  pointsReached=false;
     size_t                fillSize;
 
+    if (abortTester) {
+      return;
+    }
+
     filled.clear();
 
     // Put all filled fields in a list. This is the list of candidates.
@@ -367,6 +372,10 @@ void Sudoku::GenerateRiddle(Sudoku &riddle, size_t minimumPointLimit)
     // While there are still filled fields to check and
     // we have not found a Sudoku with exactly one solution...
     while (!filled.empty() && !foundFree) {
+      if (abortTester) {
+        return;
+      }
+
       size_t pos=(size_t)(double(filled.size())*rand()/RAND_MAX);
 
       std::vector<size_t>::iterator iter=filled.begin();
